################################################################################
################################################################################
#
#     Early Learning in South Punjab, Pakistan: 
#     Investigating Child Development and Classroom Quality
#
#     R Script 3: Analysis
#
################################################################################

################################################################################
#### Load analytical datasets                                               ####
#########################s######################################################

# Remove everything except functions
rm(list = setdiff(ls(), lsf.str()))

# Load in data
aimecd_da_analysis <- readRDS("cleandata/aimecd_da_analysis.RDS")
aimecd_da_analysis_itemsL <- readRDS("cleandata/aimecd_da_analysis_itemsL.RDS")
aimecd_da_analysis_exemplaritemsL <- readRDS("cleandata/aimecd_da_analysis_exemplaritemsL.RDS")
teachece_teacher_analysis <- readRDS("cleandata/teachece_teacher_analysis.RDS")
teachece_analysis_L_elements <- readRDS("cleandata/teachece_analysis_L_elements.RDS")
teachece_analysis_L <- readRDS("cleandata/teachece_analysis_L.RDS")
teachece_analysis_L_elements <- readRDS("cleandata/teachece_analysis_L_elements.RDS")
teachece_analysis_L_items <- readRDS("cleandata/teachece_analysis_L_items.RDS")
school_universe <- readRDS("cleandata/school_universe.RDS")

################################################################################
#### Create Figures & Tables                                                ####
################################################################################

################
#### Sample information ####
################

# Boys and girls
aimecd_da_analysis %>% 
  group_by(Sex) %>% 
  summarise(n = n())

# Number of observations in final analytical sample
nrow(teachece_teacher_analysis)
nrow(aimecd_da_analysis)

length(unique(teachece_teacher_analysis))

################
#### Table 2. Sample and project area by district compared to South Punjab ####
################

### Create a summary of the school universe by district in terms of total 
### of schools and primary enrollment in South Punjab, PHCIP, and Sample

school_summary <- school_universe %>% 
  #filter(csl_level == "Primary") %>% 
  group_by(csl_district) %>% 
  summarize(school_total = n(),
            school_phcip = sum(isProject),
            school_sample = sum(isAnalyticalSample, na.rm = TRUE),
            enroll_total = sum(primary_enroll),
            enroll_phcip = sum(primary_enroll * isProject),
            enroll_sample = sum(primary_enroll * isSample, na.rm = TRUE)) %>% 
  ungroup() %>% 
  mutate(across(-csl_district, 
                .fns = ~ round(.x / sum(.x), 3)*100,
                .names = "{.col}_pct")) %>% 
  select(csl_district, school_total:enroll_sample_pct)

### Format nicely for publication
table2 <- school_summary %>% 
  rename(District = csl_district) %>% 
  mutate(`Schools - South Punjab` = paste0(format(school_total, big.mark = ","), " \r",  "(", school_total_pct, "%)"),
         `Schools - PHCIP` = paste0(format(school_phcip, big.mark = ","), " \r", "(", school_phcip_pct, "%)"),
         `Schools - Sample` = paste0(format(school_sample, big.mark = ","), " \r", "(", school_sample_pct, "%)"),
         `Students - South Punjab` = paste0(format(enroll_total, big.mark = ","), " \r", "(", enroll_total_pct, "%)"),
         `Students - PHCIP` = paste0(format(enroll_phcip, big.mark = ","), " \r", "(", enroll_phcip_pct, "%)"),
         `Students - Sample` = paste0(format(enroll_sample, big.mark = ","), " \r", "(", enroll_sample_pct, "%)")) %>% 
  select(District, starts_with("Schools") | starts_with("Students"))

### Create a row of totals
table2totals <- school_summary %>%
  select(csl_district, school_total:enroll_sample) %>% 
  summarize(across(where(is.character), ~"Total"),
            across(where(is.numeric), ~format(sum(.x), big.mark = ",")))
  names(table2totals) = names(table2) #Allow names to line up

### Combine and write out
bind_rows(table2, table2totals) %>% 
  write_xlsx(path = "output/Table2.xlsx")

################
#### Table 6. Cronbach’s Alpha of AIM-ECD Domain and Teach ECE Areas ####
################
#### AIM-ECD Reliability ####
Early_Lit_alpha <- aimecd_da_analysis %>%
  select(dal_lc01:dal_nw01) %>%
  as.data.frame() %>%
  psych::alpha(check.keys = FALSE,
               title = "Early_Lit")

Early_Numeracy_alpha <- aimecd_da_analysis %>%
  select(dan_sv01:dan_si_05) %>%
  as.data.frame() %>%
  psych::alpha(check.keys = FALSE,
               title = "Early_Numeracy")

Executive_Function_alpha <- aimecd_da_analysis %>%
  dplyr::select(dae_ht01:dae_bs04) %>%
  as.data.frame() %>%
  psych::alpha(check.keys = FALSE,
               title = "Executive_Function")

Social_Emotional_alpha <- aimecd_da_analysis %>%
  dplyr::select(starts_with("das_pt0")) %>%
  as.data.frame() %>%
  psych::alpha(check.keys = FALSE,
               title = "Social_Emotional")

Overall_alpha <- aimecd_da_analysis %>%
  dplyr::select(dal_lc01:das_pt03) %>%
  as.data.frame() %>%
  psych::alpha(check.keys = FALSE,
               title = "AIM-ECD_Overall")

# Make a nice little dataframe out of everything
alphas <- rbind(
  Early_Lit_alpha$total,
  Early_Numeracy_alpha$total,
  Executive_Function_alpha$total,
  Social_Emotional_alpha$total,
  Overall_alpha$total) %>%
  dplyr::select(raw_alpha, std.alpha, mean, sd)

alphas$domain <- c("AIM-ECD Early Literacy", "AIM-ECD Early Numeracy", 
                   "AIM-ECD Executive Functioning", "AIM-ECD Social Emotional", 
                   "AIM-ECD Overall")

#### Teach ECE Reliability ####
### Note: This is using the behaviors from the long dataset 
ClassroomCulture_alpha_behavL <- teachece_analysis_L %>% 
  dplyr::select(c11:c23) %>% 
  as.data.frame() %>% 
  psych::alpha(check.keys = FALSE,
               title = "Classroom Culture")

GuidedLearning_alpha_behavL <- teachece_analysis_L %>%
  dplyr::select(c31:c63) %>% 
  as.data.frame() %>% 
  psych::alpha(check.keys = FALSE,
               title = "Guided Learning")

SocioEmotionalSkills_alpha_behavL <- teachece_analysis_L %>%
  dplyr::select(c71:c93) %>% 
  as.data.frame() %>% 
  psych::alpha(check.keys = FALSE,
               title = "Social Emotional Skills")

TeachECEOverall_alpha_behavL <- teachece_analysis_L %>%
  dplyr::select(c11:c93) %>% 
  as.data.frame() %>% 
  psych::alpha(check.keys = FALSE,
               title = "Teach ECE Overall")

#Make a nice little dataframe out of everything 
teachece_alphas <- rbind(
  ClassroomCulture_alpha_behavL$total,
  GuidedLearning_alpha_behavL$total, 
  SocioEmotionalSkills_alpha_behavL$total, 
  TeachECEOverall_alpha_behavL$total) %>% 
  dplyr::select(raw_alpha, std.alpha, mean, sd)

teachece_alphas$domain <- c("Teach ECE: Classroom Culture", "Teach ECE: Guided Learning", 
                              "Teach ECE: SocioEmotional Skills", "Teach ECE: Overall")

alphas <- rbind(alphas, teachece_alphas) %>% 
  relocate(domain)

stargazer::stargazer(alphas,
                     summary = FALSE,
                     type = "text",
                     out = "output/Table 6.txt",
                     header=FALSE,
                     digits = 3,
                     table.placement = "!h",
                     title = "Teach ECE Reliability Estimates"
)



################
#### Table 7. Number of Classrooms by Grade and Multi-graded Status ####
################

# Types of classes
teachece_teacher_analysis %>% 
  group_by(Class, Multigrade_Class) %>% 
  summarize(n = n()) %>% 
  write_xlsx(path = "output/Table7.xlsx")

################
#### Figure 5. Average and Median Enrollment Size by Class Type ####
################

# Average and Median Enrollment and Attendance by Class Type
teachece_teacher_analysis %>% 
  summarize(enrollment_mean = mean(n_enroll2),
            attendance_mean = mean(class_total_present),
            enrollment_median = median(n_enroll2),
            attendance_median = median(class_total_present))

# Average and Median Enrollment Size by Class Type
teachece_teacher_analysis %>%
  group_by(Class) %>% 
  summarize(enrollment_mean = mean(n_enroll2),
            attendance_mean = mean(class_total_present),
            enrollment_median = median(n_enroll2),
            attendance_median = median(class_total_present)) %>% 
  pivot_longer(c(enrollment_mean, enrollment_median)) %>%
  mutate(stat = ifelse(grepl("mean", name), "Mean", "Median"),
         name = ifelse(grepl("enroll", name), "Enrollment", "Attendance")) %>% 
  ggplot(aes(x = Class, y = value, label = round(value,2), fill = Class, goup = stat))  +
  geom_bar(stat = "identity", position = position_dodge()) +
  # geom_errorbar(width = .25, alpha = .3) +
  geom_text(vjust = -.5) +
  labs(x = "Type of classroom", 
       y = "Enrollment/Attendance",
       fill = "") +
  theme(legend.position = "none") + 
  scale_fill_brewer(palette = "Set2") +
  facet_grid(~stat)
ggsave("output/Figure5.png", width = 5.5, height = 5)

################
#### Figure 6. Distribution of Attendance on Day of Observation ####
################
enrollment_attendance <- teachece_teacher_analysis %>%
  select(merge_class_id, Class, n_enroll2, class_total_present, starts_with("enrollment"), starts_with("present")) %>%
  mutate(n_enroll_boys = enrollment_boy_less_3 + enrollment_boy_3 + enrollment_boy_4 + enrollment_boy_5 + enrollment_boy_6 + enrollment_boy_greater_6,
         n_enroll_girls = enrollment_girls_less_3 + enrollment_girls_3 + enrollment_girls_4 + enrollment_girls_5 + enrollment_girls_6 + enrollment_girls_greater_6,
         n_attend_boys = present_boys_less_3 + present_boys_3 + present_boys_4 + present_boys_5 + present_boys_6 + present_boys_greater_6,
         n_attend_girls = present_girls_less_3 + present_girls_3 + present_girls_4 + present_girls_5 + present_girls_6 + present_girls_greater_6) %>%
  mutate(present = class_total_present / n_enroll2,
         present_boys = n_attend_boys / n_enroll_boys,
         present_girls = n_attend_girls / n_enroll_girls)

enrollment_attendance %>% 
  mutate(below = ifelse(present <= .75, "Below 75% present", "At least 75% present")) %>% 
  ggplot(aes(x = present, fill = below)) +
  geom_histogram(aes(y = after_stat(count / sum(count)), fill = below), breaks = seq(0,1, by = .05)) +
  scale_x_continuous(labels = scales::percent, limits = c(0,1))  + 
  labs(x = "Percent of children in attendance on date of observation",
       y = "Percent of classess",
       fill = "") +
  theme(legend.position = "bottom") + 
  scale_fill_brewer(palette = "Set2") +
  scale_y_continuous(labels = scales::percent)
ggsave("output/Figure6.png", width = 8, height = 6)

mean(enrollment_attendance$present < .75)


################
#### Figure 7. Average Number of Children Enrolled and Present in Classrooms by Age and Sex 
################

# Figure 7. Average Number of Children Enrolled and Present in Classrooms by Age and Sex -- ENROLLED
enrollment_attendanceL <- enrollment_attendance %>% 
  select(merge_class_id, Class, starts_with("enrollment"), starts_with("present")) %>%
  select(-c(present,present_boys,present_girls)) %>% 
  pivot_longer(cols = c(starts_with("enrollment"), starts_with("present"))) %>% 
  mutate(sex = ifelse(grepl("boy", name), "Boys", "Girls"),
         enrollment = ifelse(grepl("enroll", name), "Enrollment", "Attendance")) %>% 
  mutate(name = ifelse(name %in% c("enrollment_boy_less_3", "enrollment_girls_less_3", "present_boys_less_3", "present_girls_less_3"), "2", name),
         name = ifelse(name %in% c("enrollment_boy_greater_6", "enrollment_girls_greater_6", "present_boys_greater_6", "present_girls_greater_6"), "7",  name)) %>% 
  mutate(age = parse_number(name),
         age_fac = factor(age, labels = c("Less than 3", "3", "4", "5", "6", "Greater than 6")))

enrollment_attendance %>%
  select(n_enroll_boys, n_enroll_girls) %>% 
  summary()

enrollment_attendanceL %>%
  group_by(sex, age_fac, enrollment) %>% 
  summarize(value = mean(value)) %>% 
  ggplot(aes(x = age_fac, y = value, fill = sex)) + 
  geom_bar(position = "dodge", width = .5, stat = "identity") +
  geom_text(aes(label = round(value, 2)), stat = "identity", position = position_dodge(1), vjust = -.5, size = 2.5) +
  theme(legend.position = "bottom") + 
  scale_fill_brewer(palette = "Set2") +
  labs(x = "Age", y = "Average number of children",
       fill = "Sex") +
  scale_y_continuous(limits = c(0, 7)) +
  facet_wrap(~enrollment)
ggsave("output/Figure7.png", width = 8, height = 6)


################
#### Figure 8. Actual Age Composition of Classes 
################

### Estimated average age of enrolmment by class type
enrollment_attendanceL %>% 
  mutate(age_n = age*value) %>% 
  group_by(merge_class_id, Class) %>% 
  summarize(average_age = sum(age_n) / sum(value)) %>% 
  group_by(Class) %>% 
  summarize(average_age = mean(average_age))

enrollment_attendanceL %>% 
  filter(enrollment == "Enrollment") %>% 
  group_by(age_fac, Class) %>% 
  summarize(enrollment = sum(value)) %>% 
  group_by(Class) %>% 
  mutate(enrollment_pct = enrollment/sum(enrollment)) %>% 
  filter(enrollment_pct > .01) %>% 
  mutate(Class = factor(Class, levels = rev(levels(Class)))) %>% 
  ggplot(aes(Class, y = enrollment_pct, label = scales::percent(enrollment_pct, accuracy = 1), fill = factor(age_fac))) +
  geom_bar(position = "stack", width = .5, stat = "identity") +
  geom_text(position = position_stack(vjust = 0.5), size = 3) +
  labs(x = "Percent of students at each age in class", 
       y = "",
       fill = "Age of students") +
  scale_x_discrete(labels = ~ str_wrap(as.character(.x), 15)) +
  coord_flip() +
  scale_y_reverse() +
  theme(legend.position = "bottom", 
        axis.text.x = element_blank(), axis.ticks.x = element_blank()) +
  scale_fill_brewer(palette = "Set2")
ggsave("output/Figure8.png", width = 8, height = 6)

################
#### Teacher and Staff Characteristics
################

### Proportion of classes with 1 teacher
mean(teachece_teacher_analysis$adults_teachers == 1)

### Proportion of classes with an asssistant
mean(teachece_teacher_analysis$adults_assistants > 0)

### Gender of teachers by class type
teachece_teacher_analysis %>% 
  group_by(Teacher_Gender, Class) %>% 
  summarize(n = n()) %>% 
  filter(!is.na(Teacher_Gender)) %>% 
  group_by(Class) %>% 
  mutate(pct = n/sum(n))

################
#### Figure 9. Teacher Experience and Certification Level by Sex
################

teachece_teacher_analysis %>% 
  group_by(teacher_experience, Teacher_Gender, teacher_cert, Class) %>% 
  summarize(n = n()) %>% 
  filter(!is.na(Teacher_Gender)) %>% 
  group_by(teacher_experience, Teacher_Gender) %>% 
  summarize(n = sum(n)) %>% 
  group_by(Teacher_Gender) %>% 
  mutate(prop = n / sum(n)) %>% 
  ggplot(aes(x = teacher_experience, y = prop, label = scales::percent(prop, accuracy = 1), fill = Teacher_Gender)) +
  geom_bar(position = "dodge", width = .5, stat = "identity") +
  geom_text(stat = "identity", position = position_dodge(.5), vjust = -.5, size = 3) +
  labs(x = "Teacher experience teaching pre-primary", 
       y = "Number of teachers in sample",
       fill = "Teacher Gender") +
  theme(legend.position = "bottom") +
  scale_x_discrete(labels = ~ str_wrap(as.character(.x), 10)) +
  scale_fill_brewer(palette = "Set2")
ggsave("output/Figure9a.png", width = 5, height = 6)

teachece_teacher_analysis %>%
  filter(!is.na(Teacher_Gender)) %>% 
  group_by(teacher_cert, Teacher_Gender) %>% 
  summarize(n = n()) %>% 
  group_by(Teacher_Gender) %>% 
  mutate(prop = n / sum(n)) %>%
  ggplot(aes(y = prop, x =  teacher_cert, label = scales::percent(prop, accuracy = 1), fill = Teacher_Gender)) +
  geom_col(position = "dodge", width = .5) +
  geom_text(position = position_dodge(.5), vjust = -.5, size = 3) +
  labs(x = "Teacher Certification Level", 
       y = "Percentage of teachers in sample",
       fill = "Teacher Gender") +
  theme(legend.position = "bottom") + 
  scale_x_discrete(labels = ~ str_wrap(as.character(.x), 10)) +
  scale_fill_brewer(palette = "Set2") +
  scale_y_continuous(labels = scales::percent)
ggsave("output/Figure9b.png", width = 4, height = 6)  


################
#### Figure 10. Teacher Certification by Class Type
################
teachece_teacher_analysis %>% 
  filter(teacher_cert != "Not reported") %>% 
  group_by(Class, teacher_cert) %>% 
  summarize(n = n()) %>% 
  group_by(Class) %>% 
  mutate(prop = n / sum(n)) %>% 
  ggplot(aes(x = Class, y = prop, fill = teacher_cert, label = scales::percent(prop, accuracy = 1))) +
  geom_bar(position = "stack", width = .5, stat = "identity") +
  geom_text(position = position_stack(vjust = 0.5), size = 3) +
  labs(x = "Type of Class", 
       y = "Percent of Teachers by Certification Level",
       fill = "Certification") +
  scale_y_reverse() +
  coord_flip() +
  theme(legend.position = "bottom", 
        axis.text.x = element_blank(), axis.ticks.x = element_blank()) +
  scale_fill_brewer(palette = "Set2")
ggsave("output/Figure10.png", width = 8, height = 5)

################
#### Figure 11. Water, Sanitation, and Health Resources of Classrooms
################

teachece_teacher_analysis %>% 
  select(starts_with("wash"), Class, clean_toilet) %>% 
  rename(wash_5 = clean_toilet) %>%
  select(-wash_index) %>% 
  group_by(Class) %>% 
  summarise(across(everything(), mean)) %>% 
  pivot_longer(starts_with("wash"), values_to = "value", names_to = "name") %>% 
  mutate(name = parse_number(name),
         name = factor(name, levels = 1:5, 
                       labels = c("Clean drinking water", "Handwashing facility", "Child-friendly hand washing & toilet facilities", 
                                  "Separate toilets for girls", "Clean toilets"))) %>% 
  ggplot(aes(x = name, y = value, label = value, fill = Class)) +
  geom_col() + 
  geom_text(aes(label = scales::percent(value, accuracy = 1)),
            vjust = -.75, size = 3) +  
  scale_x_discrete(labels = ~ str_wrap(as.character(.x), 10)) +
  labs(x = "WASH Resource", 
       y = "Proportion classes with availability",
       fill = "") +
  theme(legend.position = "none", axis.text.x = element_text(vjust = 0.5, hjust=.5)) + 
  scale_y_continuous(labels = scales::percent, limits = c(0,1))  +
  scale_fill_brewer(palette = "Set2") +
  facet_wrap(~Class)
ggsave("output/Figure11.png", width = 8, height = 6)

################
#### Figure 12. Availability of Learning Materials in Classrooms
################
teachece_teacher_analysis %>%
  select(starts_with("resources"), Class) %>% 
  select(-resources) %>% 
  group_by(Class) %>% 
  summarise(across(everything(), mean)) %>% 
  pivot_longer(starts_with("resources"), values_to = "available", names_to = "resource") %>% 
  mutate(whom = ifelse(grepl("bin", resource), "% of Classes with availability", "Estimated % of Children with availability"),
         resource = parse_number(resource),
         resource = factor(resource, levels = 1:6, labels = c("Writing utensils", "Art supplies", "Fantasy Play Materials", "Educational toys/Math materials", "Blocks", "Storybooks"))) %>% 
  ggplot(aes(x = resource, y = available, fill = whom, label = available)) +
  geom_col(position = "dodge", width = .9) +
  geom_text(aes(label = scales::percent(available, accuracy = 1)),
            position = position_dodge(width = .9),
            vjust = -.75, size = 3) +  
  scale_x_discrete(labels = ~ str_wrap(as.character(.x), 20)) +
  labs(x = "Type of resource", 
       y = "Proportion classes/children with availability",
       fill = "") +
  theme(legend.position = "bottom", 
        axis.text.x = element_text(vjust = 0.5, hjust=.5, angle = 90)) + 
  scale_y_continuous(labels = scales::percent, limits = c(0,1)) +
  scale_fill_brewer(palette = "Set2") +
  facet_wrap(~Class)
ggsave("output/Figure12.png", width = 8, height = 6)

################
#### Safety Hazards
################
teachece_teacher_analysis %>% 
  pivot_longer(starts_with("safety"), values_to = "value", names_to = "name") %>%
  mutate(name = parse_number(name),
         name = factor(name, levels = 1:14,
                           labels = c("Broken or uneven floor", "Broken chairs", "Sharp or rusting play materials",
                                      "Leaking roof or holes in ceiling", "Broken windows or doors", "Inadequate natural lighting",
                                      "Inadequate ventilation", "Door which cannot be locked", "Packed/stored objects on school grounds",
                                      "Open pit/holes", "Rocky/littered playgrounds", "No fencing on school premises/school near main roads",
                                      "Exposed wiring/uncovered outlets", "Other conditions liekly to cause injury to children"))) %>%
  mutate(name = factor(name, levels = rev(levels(name)))) %>% 
  group_by(Class, name) %>% 
  summarise(pct = mean(value)) %>% 
  pivot_wider(names_from = Class, values_from = pct)

################
#### Figure 13. Proportion of Segments with Minimum Levels of Quality in Teach ECE Elements
################
teachece_analysis_L_elements %>% 
  filter(!is.na(score_bin)) %>% 
  group_by(area, element) %>% 
  summarize(prop = mean(score_bin == "Meets minimum quality")) %>% 
  ggplot(aes(x = element, y = prop, label = scales::percent(prop, accuracy = 1), fill = area)) + 
  geom_col() +
  geom_text(vjust = -.5) +
  labs(x = "Teach ECE Element", 
       y = "Proportion of Ssegments",
       fill = "Teach ECE Area") +
  scale_fill_manual(values = c("#F9A64D", "#B25593", "#E8E44A", "#5AA9B1")) +
  theme(legend.position = "bottom", axis.text.x = element_text(angle = 45, vjust = 0.5, hjust=.5)) + 
  scale_x_discrete(labels = function(x) str_wrap(x, width = 15)) +
  scale_y_continuous(labels = scales::percent)
ggsave("output/Figure13.png", width = 8, height = 6)


################
#### Appendix C: Proportion of Segments Meeting Minimum Quality Levels on Teach ECE Behaviors
################
teachece_analysis_L_items %>%
  group_by(item, item_text, area) %>%
  summarize(prop = mean(score_bin == "Meets minimum quality", na.rm = TRUE)) %>%
  ggplot(aes(x = fct_reorder(item_text, item, .desc = TRUE), y = prop, label = scales::percent(prop, accuracy = 1, size = 1), fill = area)) +
  geom_col() +
  geom_text(hjust = -.2, size = 2.5) +
  scale_x_discrete(labels = ~ str_wrap(as.character(.x), 50)) +
  labs(x = "Teach ECE Behavior (Item)",
       y = "Proportion of segments") +
  theme(legend.position = "none") +
  scale_fill_manual(values = c("#F9A64D", "#B25593", "#E8E44A", "#5AA9B1")) +
  scale_y_continuous(labels = scales::percent) +
  coord_flip()
ggsave("output/AppendixC.png",  width = 8, height = 10)

################
#### Figure 14. Proportion of Segments Meeting Minimum Quality Levels: Exemplar Teach ECE Behaviors
################
teachece_analysis_L_items %>%
  filter(exemplar == "Yes") %>%
  filter(!is.na(score_bin)) %>%
  group_by(item, item_text, area) %>%
  summarize(prop = round(mean(score_bin == "Meets minimum quality"), 2)) %>%
  ggplot(aes(x = fct_reorder(item_text, item, .desc = TRUE), y = prop, label = scales::percent(prop, accuracy = 1), fill = area)) +
  geom_col() +
  geom_text(hjust = -.2, size = 3) +
  scale_x_discrete(labels = ~ str_wrap(as.character(.x), 40)) +
  scale_fill_manual(values = c("#E8E44A", "#B25593", "#F9A64D", "#5AA9B1")) +
  labs(x = "Teach ECE Behavior (Item)",
       y = "Proportion of Segments",
       fill = "Teach ECE Area") +
  scale_y_continuous(labels = scales::percent) +
  theme(legend.position = "bottom", text=element_text(size = 10)) +
  coord_flip()
ggsave("output/Figure14.png", width = 10, height = 6)

################
#### Figure 15. Teach ECE Elements by Class Type
################

teachece_analysis_L_elements %>%
  group_by(area, element, Class) %>%
  summarize(prop = mean(score_bin == "Meets minimum quality"),
            se = sqrt(var(score_bin == "Meets minimum quality")/n())) %>%
  mutate(upper = prop + 2*se,
         lower = prop - 2*se) %>%
  ggplot(aes(y = element, x = prop, xmax = upper, xmin = lower, fill = area, group = Class)) + 
  geom_col(aes(alpha = Class), position = "dodge", width = .8) + 
  scale_fill_manual(values = c("#E8E44A", "#B25593", "#F9A64D", "#5AA9B1")) +
  scale_alpha_discrete(range = c(0.3, 1)) +
  geom_errorbar(alpha = .3, position = position_dodge(width = .8)) +
  geom_text(aes(label = scales::percent(prop, accuracy = 1)),
            position = position_dodge(width = .8),
            hjust = -.75, size = 3.5) +
  scale_y_discrete(limits = rev(levels(teachece_analysis_L_elements$element)),
                   labels = function(x) str_wrap(x, width = 20)) +  # Reverse the order of categories on y-axis
  theme(legend.position = "bottom") +
  guides(fill=guide_legend(nrow=2), alpha = guide_legend(nrow=3)) +
  labs(x = "Proportion of Segments", fill = "Area", y = "", color = "Area", alpha = "Class Type") +
  scale_x_continuous(labels = scales::percent, limits = c(0,1.05))
ggsave("output/Figure15.png", width = 8, height = 6)

################
#### Figure 16. Teach ECE Elements by Teacher Certification
################
teachece_analysis_L_elements %>% 
  filter(!is.na(teacher_cert) & teacher_cert != "Not reported") %>% 
  group_by(area, element, teacher_cert) %>% 
  summarize(prop = mean(score_bin == "Meets minimum quality"), 
            se = sqrt(var(score_bin == "Meets minimum quality")/n())) %>% 
  mutate(upper = prop + 2*se,
         lower = prop - 2*se) %>% 
  ggplot(aes(y = element, x = prop, xmax = upper, xmin = lower, fill = area, group = teacher_cert)) + 
  geom_col(aes(alpha = teacher_cert), position = "dodge", width = .8) + 
  scale_fill_manual(values = c("#E8E44A", "#B25593", "#F9A64D", "#5AA9B1")) +
  scale_alpha_discrete(range = c(0.3, 1)) +
  geom_errorbar(alpha = .3, position = position_dodge(width = .8)) +
  geom_text(aes(label = scales::percent(prop, accuracy = 1)),
            position = position_dodge(width = .8),
            hjust = -.75, size = 3.5) +
  scale_y_discrete(limits = rev(levels(teachece_analysis_L_elements$element)),
                   labels = function(x) str_wrap(x, width = 20)) +  # Reverse the order of categories on y-axis
  theme(legend.position = "bottom") +
  guides(fill=guide_legend(nrow=2), alpha = guide_legend(nrow=3)) +
  labs(x = "Proportion of Segments", fill = "Area", y = "", color = "Area", alpha = "Teacher Certification") +
  scale_x_continuous(labels = scales::percent, limits = c(0,1.05))
ggsave("output/Figure16.png", width = 8, height = 6)

################
#### Figure 17. Teach ECE Elements by Teacher Gender
################
teachece_analysis_L_elements %>% 
  filter(!is.na(Teacher_Gender)) %>% 
    group_by(area, element, Teacher_Gender) %>% 
    summarize(prop = mean(score_bin == "Meets minimum quality"), 
              se = sqrt(var(score_bin == "Meets minimum quality")/n())) %>% 
    mutate(upper = prop + 2*se,
           lower = prop - 2*se) %>% 
    ggplot(aes(y = element, x = prop, xmax = upper, xmin = lower, fill = area, group = Teacher_Gender)) + 
    geom_col(aes(alpha = Teacher_Gender), position = "dodge", width = .8) + 
    scale_fill_manual(values = c("#E8E44A", "#B25593", "#F9A64D", "#5AA9B1")) +
    scale_alpha_discrete(range = c(0.5, 1)) +
    geom_errorbar(alpha = .3, position = position_dodge(width = .8)) +
    geom_text(aes(label = scales::percent(prop, accuracy = 1)),
              position = position_dodge(width = .8),
              hjust = -.75, size = 3.5) +
    scale_y_discrete(limits = rev(levels(teachece_analysis_L_elements$element)),
                     labels = function(x) str_wrap(x, width = 20)) +  # Reverse the order of categories on y-axis
    theme(legend.position = "bottom") +
    guides(fill=guide_legend(nrow=2), alpha = guide_legend(nrow=3)) +
    labs(x = "Proportion of Segments", fill = "Area", y = "", color = "Area", alpha = "Teacher Gender") +
    scale_x_continuous(labels = scales::percent, limits = c(0,1.05))
  ggsave("output/Figure17.png", width = 8, height = 6)
  
################
#### Figure 18. Teach ECE Elements by Language of Instruction
################
teachece_analysis_L_elements %>% 
  group_by(area, element, language_used) %>% 
  summarize(prop = mean(score_bin == "Meets minimum quality"), 
            se = sqrt(var(score_bin == "Meets minimum quality")/n())) %>% 
  mutate(upper = prop + 2*se,
         lower = prop - 2*se) %>%   
  ggplot(aes(y = element, x = prop, xmax = upper, xmin = lower, fill = area, group = factor(language_used, levels = rev(levels(language_used))))) + 
  geom_col(aes(alpha = language_used), position = "dodge", width = .8) + 
  scale_fill_manual(values = c("#E8E44A", "#B25593", "#F9A64D", "#5AA9B1")) +
  scale_alpha_discrete(range = c(1, .3)) +
  geom_errorbar(alpha = .3, position = position_dodge(width = .8)) +
  geom_text(aes(label = scales::percent(prop, accuracy = 1)),
            position = position_dodge(width = .8),
            hjust = -.75, size = 3.5) +
  scale_y_discrete(limits = rev(levels(teachece_analysis_L_elements$element)),
                   labels = function(x) str_wrap(x, width = 20)) +  # Reverse the order of categories on y-axis
  theme(legend.position = "bottom") +
  guides(fill=guide_legend(nrow=2), alpha = guide_legend(nrow=3)) +
  labs(x = "Proportion of Segments", fill = "Area", y = "", color = "Area", alpha = "Language Used") +
  scale_x_continuous(labels = scales::percent, limits = c(0,1.05))
ggsave("output/Figure18.png", width = 8, height = 6)


################
#### Figure 19. AIM-ECD Exemplar Item Correct Percentage by Age
################
aimecd_da_analysis_exemplaritemsL %>% 
  group_by(Description, Age, domain) %>% 
  summarise(mean = mean(score),
            se = sqrt(var(score)/n())) %>% 
  mutate(upper = mean + 2*se,
         lower = mean - 2*se) %>% 
  ggplot(aes(y = Description, x = mean, group = Age, xmax = upper, xmin = lower, fill = domain)) + 
  geom_col(aes(alpha = as.factor(Age)), position = "dodge", width = .8) + 
  scale_alpha_discrete(range = c(.3, 1)) +
  scale_fill_manual(values = c("#66C2A5", "#8DA0CB","#FC8D62", "#E78AC3", "#A6D854")) +
  geom_errorbar(alpha = .3, position = position_dodge(width = .8)) +
  geom_text(aes(label = scales::percent(mean, accuracy = 1)),
            position = position_dodge(width = 1),
            hjust = -.75, size = 3) +
  scale_y_discrete(limits = rev(levels(aimecd_da_analysis_exemplaritemsL$Description)),
                   labels = function(x) str_wrap(x, width = 30)) +  # Reverse the order of categories on y-axis
  theme(legend.position = "bottom") +
  guides(fill=guide_legend(nrow=3)) +
  labs(x = "Percentage of children correctly responding", fill = "Domain", alpha = "Age", y = "") +
  scale_x_continuous(labels = scales::percent, limits = c(0,1.05))

ggsave("output/Figure19.png", width = 8, height = 9)

################
#### Figure 20. Exemplar Items Correct Percentage by Child Sex
################
aimecd_da_analysis_exemplaritemsL %>% 
  group_by(Description, domain, Sex) %>% 
  summarise(mean = mean(score),
            se = sqrt(var(score)/n())) %>% 
  mutate(upper = mean + 2*se,
         lower = mean - 2*se) %>% 
  ggplot(aes(y = Description, x = mean, group = Sex, xmax = upper, xmin = lower, fill = domain)) + 
  geom_col(aes(alpha = as.factor(Sex)), position = "dodge", width = .8) + 
  scale_alpha_discrete(range = c(.5, 1)) +
  scale_fill_manual(values = c("#66C2A5", "#8DA0CB","#FC8D62", "#E78AC3", "#A6D854")) +
  geom_errorbar(alpha = .3, position = position_dodge(width = .8)) +
  geom_text(aes(label = scales::percent(mean, accuracy = 1)),
            position = position_dodge(width = 1),
            hjust = -.75, size = 3) +
  scale_y_discrete(limits = rev(levels(aimecd_da_analysis_exemplaritemsL$Description)),
                   labels = function(x) str_wrap(x, width = 30)) +  # Reverse the order of categories on y-axis
  theme(legend.position = "bottom") +
  guides(fill=guide_legend(nrow=3)) +
  labs(x = "Percentage of children correctly responding", fill = "Domain", alpha = "Sex", y = "") +
  scale_x_continuous(labels = scales::percent, limits = c(0,1.05))
ggsave("output/Figure20.png", width = 8, height = 8)


