################################################################################
################################################################################
#
#     Early Learning in South Punjab, Pakistan: 
#     Investigating Child Development and Classroom Quality
#
#     R Script 2: Data Construction
#
################################################################################

################################################################################
#### Load analytical datasets                                               ####
#########################s######################################################

# Remove everything except functions
rm(list = setdiff(ls(), lsf.str()))

# Load in anonymized data
aimecd_da_anon <- readRDS("anondata/aimecd_da_anon.RDS")
program_schools <- readRDS("anondata/program_schools.RDS")
school_universe <- readRDS("anondata/school_universe.RDS")
teachece_anon <- readRDS("anondata/teachece_anon.RDS")
teachers_anon <- readRDS("anondata/teachers_anon.RDS")

# Load in helper files for labelling items
teacheceitemlabs <- readxl::read_excel("rawdata/teachece_item_labels.xlsx")
itemexemplars <- readxl::read_excel("rawdata/Item_Information.xlsx")


################################################################################
#### Create indicators                                                      ####
################################################################################

#### AIM-ECD ####
aimecd_da_merge <- aimecd_da_anon %>% 
  #Get % scores for AIM-ECD subtasks
  mutate(dal_lc_pct = rowSums(across(dal_lc01:dal_lc05) / 5),
         dal_li_pct = rowSums(across(dal_li01:dal_li20) / 20),
         dal_sd_pct = rowSums(across(dal_sd01:dal_sd03) / 3),
         dal_nw_pct = rowSums(across(dal_nw01) / 4), 
         da_e2_pct = rowSums(across(da_e2_01:da_e2_20) / 20), #ENLIGH VERSION
         dan_sv_pct = rowSums(across(dan_sv01:dan_sv04) / 4),
         dan_ps_pct = rowSums(across(dan_ps01:dan_ps04) / 4),
         dan_sa_pct = rowSums(across(dan_sa01:dan_sa03) / 3),
         dan_ni_pct = rowSums(across(dan_ni01:dan_ni20) / 20),
         dan_nc_pct = rowSums(across(dan_nc01:dan_nc03) / 3),
         dan_si_pct = rowSums(across(dan_si_01:dan_si_05) / 5),
         dae_ht_pct = rowSums(across(dae_ht01:dae_ht15) / 15),
         dae_fs_pct = rowSums(across(dae_fs01:dae_fs04) / 4),
         dae_bs_pct = rowSums(across(dae_bs01:dae_bs04) / 4),
         das_pt_pct = rowSums(dplyr::select(., das_pt01, das_pt02, das_pt03) / 3)
  ) %>% 
  #Calculate AIM-ECD Domain sores
  mutate(EarlyLiteracy = rowMeans(across(dal_lc_pct:dal_nw_pct)),
         EarlyNumeracy = rowMeans(across(dan_sv_pct:dan_si_pct)),
         ExecutiveFunction = rowMeans(across(dae_ht_pct:dae_bs_pct)),
         SocialEmotional = rowMeans(across(das_pt_pct)),
         EnglishLetter = rowMeans(across(da_e2_pct)),
         AIMECD_Overall = rowMeans(across(EarlyLiteracy:SocialEmotional))
  )  %>% 
  # Create Z-scores of each of the AIM-ECD domains
  mutate(AIMECD_Overall_Z = scale(AIMECD_Overall),
         EarlyLiteracy_Z = scale(EarlyLiteracy),
         EarlyNumeracy_Z = scale(EarlyNumeracy),
         ExecutiveFunction_Z = scale(ExecutiveFunction),
         SocialEmotional_Z = scale(SocialEmotional),
         EnglishLetter_Z = scale(EnglishLetter)) %>% 
  # Keep only the variables that we want to use in analysis
  select(childid, merge_class_id, unique_school_code, District, Tehsil, Level, female, Child_Age_Years, 
       ends_with("pct"), dal_lc01:da_e2_20, EarlyLiteracy:EnglishLetter_Z, aimecd_enumerator)
  

#### Teach ECE ####
# Calculate Teach ECE Area Scores at the observation level
teachece_merge <- teachece_anon %>%
  mutate(
    TimeOnTask_prop = rowMeans(across(ends_with("_c01"))), 
    TimeOnTask_level = rowMeans(across(ends_with("_c02"))),
    ClassroomCulture = rowMeans(dplyr::select(. , s1_q1, s1_q2, s2_q1, s2_q2)),
    GuidedLearning = rowMeans(dplyr::select(., s1_q3, s1_q4, s1_q5, s1_q6,
                                            s2_q3, s2_q4, s2_q5, s2_q6)),
    SocioEmotionalSkills = rowMeans(dplyr::select(., s1_q7, s1_q8, s1_q9,
                                                  s2_q7, s2_q8, s2_q9)),
    TeachECE_Overall = rowMeans(across(ClassroomCulture:SocioEmotionalSkills))) %>% 
  #Create Z-scores of each Teach ECE Area
  mutate(TimeOnTask_level_Z = scale(TimeOnTask_level),
         ClassroomCulture_Z = scale(ClassroomCulture),
         GuidedLearning_Z = scale(GuidedLearning),
         SocioEmotionalSkills_Z = scale(SocioEmotionalSkills),
         TeachECE_Overall_Z = scale(TeachECE_Overall)) %>% 
  #Calculate Teach ECE structural/other scores
  mutate(resources = rowSums(across(starts_with("resources") & ends_with("bin"))),
         books = rowSums(across(starts_with("books"))),
         wash_index = rowSums(across(starts_with("wash_"))),
         n_safetyhazards = rowSums(across(safety_hazards_1:safety_hazards_14))) %>% 
  mutate(Multigrade_Class = you_are_observing == "Multigrade_Class") %>% 
  mutate(Class = ifelse(Multigrade_Class, class_teaching_this_time, class)) %>% 
  mutate(Class = factor(Class, levels = c("Katchi", "ECE", "Grade_1"))) %>% 
  mutate(language_used = ifelse(language_used != "Urdu" & language_used != "Saraiki", "Other", language_used)) %>% 
  mutate(language_used = factor(language_used, levels = c("Urdu", "Saraiki", "Other"))) %>% 
  mutate(Class = ifelse(you_are_observing == "Single_Class", class, class_teaching_this_time)) %>% 
  mutate(loi_prop = ifelse(loi_prop == "None of the children speak this language at home", "None",
                           ifelse(loi_prop == "Less than half of the children speak this language at home", "Less than half", "More than half"))) %>% 
  mutate(loi_prop = factor(loi_prop, levels = c("None", "Less than half", "More than half"))) %>% 
  mutate(Class = factor(Class, levels = c("Katchi", "ECE", "Grade_1"), labels = c("Katchi", "ECE", "Grade 1"))) %>% 
  mutate(Preprimary = ifelse(Class == "Grade 1", "Grade 1", "Pre-primary")) %>%
  # Keep only the variables we want to use in the analysis
  select(merge_class_id, class_enrollment:type_of_class, starts_with("s1_q"), starts_with("s2_q"), 
         matches("(^s[12]_c[1-9])(.*)([0-9])$"), starts_with("wash_"), starts_with("seen"), 
         clean_toilet, starts_with("resources_"), starts_with("safety_hazards_"), TimeOnTask_prop:Preprimary, 
         language_used, loi_prop, loi_prop_bin, teachece_enumerator, starts_with("adults"))

#### Teachers ####
teachers_merge <- teachers_anon %>%
  mutate(teacher_cert = ifelse(teacher_BEd == 1 | teacher_MEd == 1, "B.Ed. or M.Ed",
                               ifelse(teacher_CT == 1 | teacher_PTC == 1, "PTC or CT", "None"))) %>%
  mutate(teacher_cert = factor(teacher_cert, levels = c("None", "PTC or CT", "B.Ed. or M.Ed"))) %>% 
  mutate(teacher_experience = ifelse(is.na(teacher_experience), "None reported", 
                                     ifelse(teacher_experience >= 20, "20+ years",
                                            ifelse(teacher_experience >= 10, "10-19 years",
                                                   ifelse(teacher_experience >= 6, "6-10 years",
                                                          ifelse(teacher_experience >= 3, "3-5 years",
                                                                 ifelse(teacher_experience >= 1, "1-2 years", "Less than one year"))))))) %>% 
  mutate(teacher_experience = factor(teacher_experience, levels = c("None reported", "Less than one year", "1-2 years", "3-5 years", "6-10 years", "10-19 years", "20+ years"))) %>% 
  # Keep only the variables we want to use in analysis
  select(merge_class_id, teacher_cert, teacher_experience, Teacher_Gender, teacher_enumerator)
    

################################################################################
### MERGE CHILD, TEACH ECE, AND TEACHERS DATASETS                           ####
################################################################################

# Merge the AIM-ECD, Teach ECE, and Teachers so we correctly align 
merged <- left_join(aimecd_da_merge, teachece_merge, by = "merge_class_id") %>% 
  left_join(teachers_merge, by = "merge_class_id") %>% 
  mutate(hasDA = !is.na(AIMECD_Overall),
         hasTeachECE = !is.na(TeachECE_Overall),
         hasTeacher = !is.na(teacher_cert))

merged %>% 
  summarize(across(hasDA:hasTeacher, mean))
  # Pretty good!

################################################################################
### CREATE ANALYITICAL DATASETS SUBSET FROM THE MERGED DATA                 ####
################################################################################

# Subset the data to the relevant Teachers, Classrooms, and Children
merged <- merged %>% 
  filter(Class != "ECE")

#### AIM-ECD Direct Assessment ####
### Unit of analysis: Child, clustered at teacher/classroom level
aimecd_da_analysis <- merged  %>% 
  mutate(Age = floor(Child_Age_Years),
         Sex = ifelse(female == 1, "Girls", "Boys"))

### Unit of analysis: AIM-ECD item response
aimecd_da_analysis_itemsL <- aimecd_da_analysis %>% 
  pivot_longer(dal_lc01:da_e2_20, names_to = "item", values_to = "score") %>% 
  mutate(domain = ifelse(grepl("^das", item), "Social Emotional",
                         ifelse(grepl("^dan", item), "Early Numeracy",
                                ifelse(grepl("^dal", item), "Early Literacy",
                                       ifelse(grepl("^dae", item), "Executive Functioning", "English Letters"))))) %>% 
  mutate(domain = factor(domain, levels = c("Early Literacy", "English Letters", "Early Numeracy", "Executive Functioning", "Social Emotional"))) %>% 
  mutate(item = gsub("dal_lc", "Listening Comprehension ", item, fixed = TRUE)) %>% 
  mutate(item = gsub("dal_li", "Letter Identification ", item, fixed = TRUE)) %>% 
  mutate(item = gsub("dal_sd", "Sound Discrimination ", item, fixed = TRUE)) %>% 
  mutate(item = gsub("dal_lc", "Listening Comprehension ", item, fixed = TRUE)) %>% 
  mutate(item = gsub("dal_nw", "Name Writing ", item, fixed = TRUE)) %>% 
  mutate(item = gsub("da_e2_", "English Letter Identification ", item, fixed = TRUE)) %>% 
  mutate(item = gsub("dan_sv", "Spatial Vocabulary ", item, fixed = TRUE)) %>% 
  mutate(item = gsub("dan_ps", "Producing a Set ", item, fixed = TRUE)) %>% 
  mutate(item = gsub("dan_sa", "Simple Addition ", item, fixed = TRUE)) %>% 
  mutate(item = gsub("dan_ni", "Number Identification ", item, fixed = TRUE)) %>% 
  mutate(item = gsub("dan_nc", "Number Comparison ", item, fixed = TRUE)) %>% 
  mutate(item = gsub("dan_si_", "Shape Identification ", item, fixed = TRUE)) %>% 
  mutate(item = gsub("dae_ht", "Head Toes Knees Shoulder Task ", item, fixed = TRUE)) %>% 
  mutate(item = gsub("dae_fs", "Forward Digit Span ", item, fixed = TRUE)) %>% 
  mutate(item = gsub("dae_bs", "Backward Digit Span ", item, fixed = TRUE)) %>% 
  mutate(item = gsub("das_pt", "Empathy Perspective Taking ", item, fixed = TRUE))

### Unit of analysis: AIM-ECD item response
aimecd_da_analysis_exemplaritemsL <- left_join(aimecd_da_analysis_itemsL, itemexemplars, by = "item") %>% 
  mutate(score = ifelse(item == "Name Writing 01" & score >= 3, 1,
                        ifelse(item == "Name Writing 01" & score < 3, 0, score))) %>% 
  filter(Exemplar == 1) %>% 
  rename(domain = domain.x) %>% 
  mutate(Description = factor(Description, levels = c("Identified Urdu letter Alif", "Identified Urdu letter Choti ye",
                                                      "Identified color of hat from story", "Wrote at least some letters when asked to write name", 
                                                      "Identified word starting with /s/ sound","Identified numeral 1 presented out of sequence", 
                                                      "Identified numeral 10 presented out of sequence" ,"Counted 6 objects correctly", "Counted 14 objects correctly", 
                                                      "Identified a circle among shapes", "Identified a triangle among shapes", "Added 2+1=3",
                                                      "Correctly understood spatial vocabulary for under", "Identified English letter A", 
                                                      "Identified English letter Z", "Could repeat 2 digits in revserse order", 
                                                      "Could repeat 3 digits in same order", "Correctly followed instructions of a confusing task",  "Could identify emotion crying girl was feeling"))) 

#### Teach ECE Wide & Teacher #### 
### Unit of analysis: Classroom
# Create a "wide" dataset at the classroom level that 
teachece_teacher_analysis <- merged %>% 
  group_by(merge_class_id) %>% 
  summarize(across(everything(), first)) %>% # Take the first observation by each merge_id
  select(merge_class_id:Level, class_enrollment:hasTeacher) %>% 
  ungroup()

#### Teach ECE Long #### 
### Unit of analysis: Sweep
# Create a "long" dataset of Teach ECE data by sweep (2 per class)
teachece_analysis_L <- merged %>% 
  select(-c(female:AIMECD_Overall)) %>% 
  mutate(s1_q0 = TimeOnTask_level,
         s2_q0 = TimeOnTask_level) %>% 
  relocate(s1_q0, .before = s1_q1) %>% 
  relocate(s2_q0, .before = s2_q1) %>% 
  pivot_longer(cols = s1_q0:s2_c93, 
               names_to = c("s", ".value"), 
               names_sep = "_") %>% 
  mutate(sweep = parse_number(s))

# Create a "longer" dataset of Teach ECE Elements by sweep (2 per class)
teachece_analysis_L_elements <- teachece_analysis_L %>% 
  select(-c(c11:c93)) %>% 
  pivot_longer(cols = q0:q9,
               values_to = "score", names_to = "item") %>% 
  mutate(area = ifelse(parse_number(item) == 0, "Time on Task",
                       ifelse(parse_number(item) <= 2, "Classroom Culture",
                              ifelse(parse_number(item) <= 6, "Guided Learning", "Socioemotional Skills")))) %>% 
  mutate(element = ifelse(item == "q1", "Supportive Learning Environment", 
                       ifelse(item == "q2", "Positive Behavioral Expectations", 
                              ifelse(item == "q3", "Facilitation of Learning", 
                                     ifelse(item == "q4", "Checks for Understanding",
                                            ifelse(item == "q5", "Feedback",
                                                   ifelse(item == "q6", "Critical Thinking",
                                                          ifelse(item == "q7", "Autonomy",
                                                                 ifelse(item == "q8", "Perserverance", 
                                                                        ifelse(item == "q9", "Social & Collaborative Skills", "Time on Task")))))))))) %>% 
  mutate(element = factor(element, levels = c("Time on Task", 
                                        "Supportive Learning Environment", 
                                        "Positive Behavioral Expectations", 
                                        "Facilitation of Learning", 
                                        "Checks for Understanding",
                                        "Feedback",
                                        "Critical Thinking",
                                        "Autonomy",
                                        "Perserverance", 
                                        "Social & Collaborative Skills"))) %>% 
  mutate(score_bin = ifelse(score >= 3, "Meets minimum quality", "Does not meet minimum quality")) %>% 
  mutate(score_bin = ifelse(element == "Time on Task" & score >= 2, "Meets minimum quality", score_bin)) %>% 
  select(-item)

# Create a "long" dataset of Teach ECE ITEMS by sweep (2 per class)
teachece_analysis_L_items <- teachece_analysis_L %>% 
  select(-c(q1:q9)) %>% 
  mutate(c01 = TimeOnTask_prop,
         c02 = TimeOnTask_level) %>% 
  relocate(c01:c02, .before = c11) %>% 
  pivot_longer(cols = c01:c93,
               names_to = "item",
               values_to = "score") %>% 
  mutate(score = ifelse(score == 0, NA, score)) %>% 
  mutate(score_bin = ifelse(score >= 2, "Meets minimum quality", "Does not meet minimum quality")) %>% 
  mutate(score_bin = ifelse(item == "c01" & score > .5, "Meets minimum quality", score_bin)) %>% 
  mutate(score_bin = ifelse(item == "c02" & is.na(score), "Does not meet minimum quality", score_bin)) %>% 
  left_join(teacheceitemlabs, by = "item")


################################################################################
### SCHOOL SAMPLE AND UNIVERSE DESCRIPTIVES                                 ####
################################################################################

school_universe <- school_universe %>% 
  # Create an indicator if each school is in the project
  mutate(isProject = !is.na(SchoolName),
         # Create an indicator if each eachool is in the baseline sample
         isSample = `Baseline Sample 900 Schools` == "Yes",
         # Create an indicator if each 
         isAnalyticalSample = emis %in% aimecd_da_analysis$unique_school_code)

################################################################################
### SAVE ANALYTICAL DATASETS                                               ####
################################################################################

# Save clean datafiles for use in R with constructed data
saveRDS(aimecd_da_analysis, "cleandata/aimecd_da_analysis.RDS")
saveRDS(aimecd_da_analysis_itemsL,"cleandata/aimecd_da_analysis_itemsL.RDS")
saveRDS(aimecd_da_analysis_exemplaritemsL, "cleandata/aimecd_da_analysis_exemplaritemsL.RDS")
saveRDS(teachece_teacher_analysis, "cleandata/teachece_teacher_analysis.RDS")
saveRDS(teachece_analysis_L_elements, "cleandata/teachece_analysis_L_elements.RDS")
saveRDS(teachece_analysis_L, "cleandata/teachece_analysis_L.RDS")
saveRDS(teachece_analysis_L_elements, "cleandata/teachece_analysis_L_elements.RDS")
saveRDS(teachece_analysis_L_items, "cleandata/teachece_analysis_L_items.RDS")
saveRDS(school_universe, "cleandata/school_universe.RDS")

# Save a datafile for Stata analyses
readstata13::save.dta13(aimecd_da_analysis, file = "cleandata/analysis_data.dta")