################################################################################
################################################################################
#
#     Early Learning in South Punjab, Pakistan: 
#     Investigating Child Development and Classroom Quality
#
#     R Script 1: Loading and Cleaning Data
#
################################################################################

################################################################################
### LOAD IN RAW DATASETS
################################################################################

#### Directly collected data (with identifiers) ####
# AIM-ECD Direct Assessment
aimecd_da_raw <- readstata13::read.dta13("rawdata/Pak_Punjab2022_clean.dta")

# List of enumerators for AIM-ECD
aimecd_enumerators_raw <- readxl::read_excel("rawdata/child_enumerators_clean.xlsx", trim_ws = FALSE)

# Teach ECE 
teachece_raw <- readstata13::read.dta13("rawdata/teach_labelled.dta")

# List of enumerators for Teach ECE
teachece_enumerators_raw <- readxl::read_excel("rawdata/teachece_enumerators_clean.xlsx",
                                               trim_ws = FALSE)

# Teachers
teachers_raw <- readstata13::read.dta13("rawdata/Module 6 -teacher dataset_d.dta")

#### Secondary data and helper files (e.g. labeling files)

# List of program schools
program_schools_raw <- readxl::read_excel("rawdata/PHCIP 3400 Schools with Baseline Sample 900 Schools Tagged.xlsx")

# List of all schools in universe
school_universe_raw <- readxl::read_excel("rawdata/dataset for HCI Districts having primary portion K-5 only.xlsx")

# Teach ECE item labels
teacheceitemlabs <- readxl::read_excel("rawdata/teachece_item_labels.xlsx")

# AIM-ECD item information
itemexemplars <- readxl::read_excel("rawdata/Item_Information.xlsx")

################################################################################
### CREATE CLEANING FUNCTIONS                                                ####
################################################################################

### Create a function to check if a variable is unique and has no missingness
is.id <- function(variable)  {
  (length(unique(variable)) == (length(variable))) & (sum(is.na(variable)) == 0)
}

### make some convenience functions for converting strings to numeric in AIM-ECD
decode_aimecd <- function(var) {
  var <- ifelse(var == "Correct", 1, 
                ifelse(var == "99", 99, 0)) 
  var
}

decode_aimecd_hskt <- function(var) {
  var <- ifelse(var == "Correct" | var == "Self-correct", 1, 
                ifelse(var == "99", 99, 0))
  var
}

decode_aimecd_urdu <- function(var) {
  var <- ifelse(var == "Correct in Urdu" | var == "Correct in other language", 1,
                ifelse(var == "99", 99, 0))
  var
}

################################################################################
#### CREATE UNIQUE IDS AND CHECK FOR DUPLICATES                             ####
################################################################################

#### AIM-ECD Direct Assessment ####
# Already has a unique id (childid), also create a merge_class_id to merge with 
# teacher and classroom data
aimecd_da <- aimecd_da_raw %>% 
  filter(assent == 1) %>% # Only include observations with children that assented
  rename(unique_school_code = center) %>% 
  mutate(merge_class_id = paste(unique_school_code, Teacher_Code, sep = "_")) 

# Investigate duplicated child ID
is.id(aimecd_da$childid)
  # Good, no duplicated childid

#### Teach ECE ####
# Create a unique ID based on school code and Teacher Code
  teachece <- teachece_raw %>% 
    mutate(merge_class_id = paste(unique_school_code, teacher_code, sep = "_")) %>% 
    rename_all(~stringr::str_replace(.,"^group_","")) %>%
    select(-matches("note")) 
  
# Investigate duplicated merge_class_id 
is.id(teachece$merge_class_id) 
  # Need to investigate more
teachece_dups <- teachece %>% 
  group_by(merge_class_id) %>% 
  mutate(n = max(row_number())) %>% 
  filter(n > 1) %>% 
  select(merge_class_id, group0teacher_name, date)
  # View(teachece_dups)
  # Teach ECE dups look like classes observed twice. We keep the first observation
teachece <- teachece %>% 
  group_by(merge_class_id) %>% 
  mutate(nthobs = seq_along(merge_class_id)) %>% 
  filter(nthobs == 1)

#### Teachers ####

# Create a unique ID based on school code and Teacher Code
teachers <- teachers_raw %>% 
  mutate(Teacher_Id = parse_number(Teacher_Id),
         Teacher_Id = ifelse(Teacher_Id >4, NA, Teacher_Id),
         merge_class_id = paste(unique_school_code2, Teacher_Id, sep = "_")) %>% 
  ### The code below is added to fix merge_class_id after checking duplicates
  mutate(merge_class_id = ifelse(merge_class_id == "31240241_2" & Teacher_Name == "Adila preveen", "31240241_3", merge_class_id),
         merge_class_id = ifelse(merge_class_id == "32230112_3" & Teacher_Name == "Farzan shair muhamd", "32230112_2", merge_class_id),
         merge_class_id = ifelse(merge_class_id == "32230434_3" & Teacher_Name == "Azara bano", "32230434_2", merge_class_id),
         merge_class_id = ifelse(merge_class_id == "36620073_2" & Teacher_Name == "Liaqat Ali", "36620073_3", merge_class_id),
         merge_class_id = ifelse(merge_class_id == "32230667_3" & Teacher_Name == "M azam", "32230667_2", merge_class_id),
         merge_class_id = ifelse(merge_class_id == "38210608_2" & Teacher_Name == "3820111836334", "38210608_3", merge_class_id),
         merge_class_id = ifelse(merge_class_id == "38210873_3" & Teacher_Name == "Gulam sakina", "38210873_2", merge_class_id))

# Investigate duplicated merge_class_id 
teachers_dups <- teachers %>% 
  group_by(merge_class_id) %>% 
  mutate(n = n()) %>% 
  filter(n>=2) %>% 
  arrange(merge_class_id) %>% 
  select(enum_name, Teacher_Name, School_Name, Survey_Day, unique_school_code2)
 # View(teachers_dups)
  # Good--there are no more duplicates
  
# Compare names of teachers to Teach ECE list
# This code was used to investigate and correct duplicates by cross-checking  
teachece %>% 
  select(group0teacher_name, merge_class_id, unique_school_code) %>% 
  filter(unique_school_code  %in% teachers_dups$unique_school_code2)
  # Good--there are no more duplicates
  

# ### List of program schools
# program_schools <- program_schools_raw %>% 
#   rename(emis = Emiscode)
# 
# ### School universe
# school_universe <- school_universe_raw %>% 
#   rename(emis = csl_emis_code,
#          primary_enroll = `current_primary(K-5)_enrollment`)


################################################################################
### FIX OVERLAP ERRORS THAT WILL MAKE MERGING DIFFICULT                     ####
################################################################################

### Teach ECE <-> Teachers ####
# Teachers in Teach ECE?
teachers_noteachece <- teachers %>% 
  filter(!(merge_class_id %in% teachece$merge_class_id)) %>% 
  select(merge_class_id, School_Code_1, School_Name, Teacher_Name) %>% 
  arrange(School_Code_1)
# View(teachers_noteachece)  
length(teachers_noteachece$merge_class_id)
# 16 teachers not in Teach ECE data

# Teach ECE in Teachers?
teachece_noteachers <- teachece %>% 
  filter(!(merge_class_id %in% teachers$merge_class_id)) %>% 
  select(merge_class_id, school_name, unique_school_code, group0teacher_name)  %>% 
  arrange(unique_school_code)
# View(teachece_noteachers)
length(teachece_noteachers$merge_class_id)
# 23 classes teachers not in Teach ECE data

# Check if overlap in missing IDs 
teachers_noteachece$School_Code_1 %in% teachece_noteachers$unique_school_code
# Looks like we can fix all the missing Teachers from Teach ECE
# view(teachers_noteachece)
# view(teachece_noteachers)

# Update the teachers with corrected merge_class_id from Teach ECE
teachers <- teachers %>% 
  mutate(merge_class_id = ifelse(merge_class_id == "31120644_2", "31120644_4", merge_class_id),
         merge_class_id = ifelse(merge_class_id == "31250045_1", "31250045_3", merge_class_id),
         merge_class_id = ifelse(merge_class_id == "32110260_1", "32110260_3", merge_class_id),
         merge_class_id = ifelse(merge_class_id == "32120543_2", "32120543_4", merge_class_id),
         merge_class_id = ifelse(merge_class_id == "32120760_2", "32120760_4", merge_class_id),
         merge_class_id = ifelse(merge_class_id == "32210052_NA", "32210052_3", merge_class_id),
         merge_class_id = ifelse(merge_class_id == "32210081_2", "32210081_4", merge_class_id),
         merge_class_id = ifelse(merge_class_id == "32210081_1", "32210081_3", merge_class_id),
         merge_class_id = ifelse(merge_class_id == "32220533_2", "32220533_4", merge_class_id),
         merge_class_id = ifelse(merge_class_id == "32320224_1", "32320224_2", merge_class_id),
         merge_class_id = ifelse(merge_class_id == "32320626_4", "32320626_2", merge_class_id),
         merge_class_id = ifelse(merge_class_id == "32330347_4", "32330347_3", merge_class_id),
         merge_class_id = ifelse(merge_class_id == "38210193_2", "38210193_3", merge_class_id),
         merge_class_id = ifelse(merge_class_id == "38130230_1", "38130230_3", merge_class_id),
         merge_class_id = ifelse(merge_class_id == "38210262_2", "38210262_4", merge_class_id),
         merge_class_id = ifelse(merge_class_id == "38320878_1", "38320878_3", merge_class_id))

# Confirm this did not create any duplicate IDs in Teacher dataset
is.id(teachers$merge_class_id)
# Good.


#### Teach ECE <-> AIM-ECD ####

# AIM-ECD in Teach ECE? 
aimeced_noteachece <- aimecd_da %>% 
  select(School_Name, unique_school_code, merge_class_id, Teacher_Name) %>% 
  filter(!(merge_class_id %in% teachece$merge_class_id))
length(aimeced_noteachece$merge_class_id)
length(unique(aimeced_noteachece$merge_class_id))
# 57 children in 11 classes are not recorded in the Teach ECE data
aimeced_noteachece <- aimeced_noteachece %>% 
  group_by(merge_class_id) %>% 
  summarize(across(everything(), first))


# Teach ECE in AIM-ECD?  
teachece_noaimecd <- teachece %>% 
  select(group0teacher_name, unique_school_code, merge_class_id, school_name) %>% 
  filter(!(merge_class_id %in% aimecd_da$merge_class_id))
length(teachece_noaimecd$merge_class_id)
# 6 classes are not recorded in the AIM-ECD data

# Check if overlap in missing IDs 
teachece_noaimecd$unique_school_code %in% aimeced_noteachece$unique_school_code
# Does not appear to overlap at all. Does not appear to be possible to fix

################################################################################
### CLEAN DATASETS                                                          ####
################################################################################

#### AIM-ECD Direct Assessment ####
# Remove nuisance variables, calculate refusals and convert relevant variables to numeric
aimecd_da_clean <-  aimecd_da %>%
  # Remove intermediate calculations on AIM-ECD items 
  select(-ends_with("correct"), -ends_with("Stop"), -matches("cont"), 
         -ends_with("text"), -ends_with("cont1"), -ends_with("cont2")) %>%
  # Convert factors to character to allow functions
  mutate(across(where(is.factor), as.character)) %>% 
  # Make Refused/Skipped "99" everywhere
  mutate(across(where(is.character), ~ifelse(.x == "Refused/Skipped", "99", .x))) %>% 
  # Count Refused/Skipped responses for each subtask
  mutate(dal_lc_refuse = rowSums(across(dal_lc01:dal_lc05) == "99", na.rm = TRUE),
         dal_li_refuse = rowSums(across(dal_li01:dal_li20) == "99", na.rm = TRUE),
         dal_nw_refuse = rowSums(across(dal_nw01) == "99", na.rm = TRUE),
         dal_sd_refuse = rowSums(across(dal_sd01:dal_sd03) == "99", na.rm = TRUE),
         dan_sv_refuse = rowSums(across(dan_sv01:dan_sv04) == "99", na.rm = TRUE),
         dan_ps_refuse = rowSums(across(dan_ps01:dan_ps04) == "99", na.rm = TRUE),
         dan_sa_refuse = rowSums(across(dan_sa01:dan_sa03) == "99", na.rm = TRUE),
         dan_ni_refuse = rowSums(across(dan_ni01:dan_ni20) == "99", na.rm = TRUE),
         dan_nc_refuse = rowSums(across(dan_nc01:dan_nc03) == "99", na.rm = TRUE),
         dan_si_refuse = rowSums(across(dan_si_01:dan_si_05) == "99", na.rm = TRUE),
         dae_ht_refuse = rowSums(across(dae_ht01:dae_ht15) == "99", na.rm = TRUE),
         dae_fs_refuse = rowSums(across(dae_fs01:dae_fs04) == "99", na.rm = TRUE),
         dae_bs_refuse = rowSums(across(dae_bs01:dae_bs04) == "99", na.rm = TRUE),
         das_pt_refuse = rowSums(across(das_pt01:das_pt03) == "99", na.rm = TRUE),
         da_e2_refuse = rowSums(across(da_e2_01:da_e2_20) == "99", na.rm = TRUE)) %>% 
  # Count number of tasks for each child with Refused/Skipped
  mutate(total_refused = rowSums(across(dal_lc_refuse:das_pt_refuse) > 2, na.rm = TRUE)) %>% 
  #Convert AIM-ECD DA data to numeric
  mutate(
    across(dal_lc01:dal_sd03, decode_aimecd),
    dal_nw01 = parse_number(as.character(dal_nw01)),
    across(dan_sv01:dan_sa03, decode_aimecd),
    across(dan_ni01:dan_ni10, decode_aimecd_urdu),
    across(dan_ni11:dan_nc03, decode_aimecd_urdu),
    across(dan_si_01:dan_si_04, decode_aimecd),
    across(dae_ht01:dae_ht15, decode_aimecd_hskt),
    across(dae_fs01:dae_bs04, decode_aimecd),
    das_pt01 = decode_aimecd(das_pt01),
    das_pt02 = decode_aimecd(das_pt02),
    das_pt03 = decode_aimecd(das_pt03),
    across(da_e2_01:da_e2_10, decode_aimecd),
    across(da_e2_11:da_e2_20, decode_aimecd)
  ) %>% 
  #Convert NA to 0 scores for calculations
  mutate(
    across(dal_lc01:da_e2_20, ~replace_na(.x, 0)), #Missing due to skip logic
    across(dal_lc01:da_e2_20, ~replace(.x, .x == 99, 0))) #Refused/Skipped

# Drop observations if more than 7 subtasks have more than 2 Refused/Skipped responses
table(aimecd_da_clean$total_refused)
aimecd_da_clean <- aimecd_da_clean %>% 
  filter(total_refused < 8)


#### Teach ECE ####
teachece_clean <- teachece %>% 
  ungroup() %>% 
  rename_all(~stringr::str_replace(.,"^s[12]_[1-9]","")) %>% 
  rename_all(~stringr::str_replace(.,"^group[127]","")) %>% 
  # Convert time-on-task data to numeric
  mutate(across(ends_with("_c01"), ~if_else(.x == "Y", 1, 0 ) )) %>%  
  mutate(across(ends_with("_c02"), ~if_else(is.na(.x), 0,
                                            if_else(.x == "H", 3,
                                                    if_else(.x == "M", 2, 1))))) %>%
  # Convert Teach ECE L M H scores to numeric
  mutate(across(where(is.character) & matches("^s[12]_") & !matches("subject"),
                ~if_else(is.na(.x), 0,
                         if_else(.x == "H", 3,
                                 if_else(.x == "M", 2, 1))))) %>%
  # Convert structural quality scores to numeric
  mutate(across(where(is.character) & starts_with("seen"),
                ~if_else(.x == "Yes", 1, 0))) %>%
  mutate(n_safetyhazards = across(starts_with("safety_hazards_"))) %>%
  mutate(across(wash_1:wash_4,~if_else(.x == "Yes", 1, 0))) %>%   #Convert wash from factor to numeric
  mutate(clean_toilet = if_else(clean_toilet == "Yes", 1, 0)) %>%   #One sneaky WASH indicator is not named nicely
  mutate(across(resources_1:resources_6,~if_else(.x < 25, 0, .x/100))) #Convert wash from factor to numeric



#### Teachers ####
teachers_clean <- teachers %>% 
  rename(teacher_ed = C1,
         teacher_qual = C2,
         teacher_nocert = C20,
         teacher_PTC = C21,
         teacher_CT = C22,
         teacher_BEd = C23,
         teacher_MEd = C24,
         teacher_experience = A7)


################################################################################
### COMBINE ENUMERATOR LISTS WITH CLEANED DATA                              ####
################################################################################

#### AIM-ECD ####
aimecd_da_clean <- left_join(aimecd_da_clean, aimecd_enumerators_raw, by = "enumerator_select") %>%
  rename(child_enumerator = enumerator) %>%
  mutate(child_enumerator = ifelse(is.na(child_enumerator), "Unknown", child_enumerator))

### Teach ECE ####
teachece_clean <- left_join(teachece_clean, teachece_enumerators_raw, by = "enumerator_name") %>% 
  rename(teachece_enumerator = enumerator_clean)

################################################################################
### CONSOLIDATE SECONDARY DATA SOURCES                                      ####
################################################################################

program_schools <- program_schools_raw %>% 
  rename(emis = Emiscode)

saveRDS(program_schools, "anondata/program_schools.RDS")

school_universe <- school_universe_raw %>% 
  rename(emis = csl_emis_code,
         primary_enroll = `current_primary(K-5)_enrollment`) %>% 
  full_join(program_schools, by = "emis") %>% 
  select(-c(csl_school_name, csl_markaz, csl_principal_name:csl_phone_no, ))
saveRDS(school_universe, "anondata/school_universe.RDS")

################################################################################
### ANONYMIZE AND SAVE DATASETS                                             ####
################################################################################
teachece_anon <- teachece_clean %>% 
  select(-c(school_name, enumerator_mobile, school_inforhead_teacher_name,
            school_inforhead_teacher_name, school_inforhead_teacher_contact,
            group0teacher_name:group0enumerator_cnic)) %>% 
  # Replace the enumerator name with a code  
  mutate(teachece_enumerator = as.numeric(as.factor(enumerator_name))) %>% 
  select(-c(enumerator_name, enumerator_id))
saveRDS(teachece_anon, "anondata/teachece_anon.RDS")


aimecd_da_anon <- aimecd_da_clean %>% 
  select(-c(School_Name, Permanent_Address:Head_Teacher_Name, childname:childfathername,
            Markaz, Moza, Teacher_Name, Teacher_Mobile, Teacher_Cnic)) %>% 
  # Replace the enumerator name with a code  
  mutate(aimecd_enumerator = as.numeric(as.factor(child_enumerator))) %>% 
  select(-c(enumerator_select, child_enumerator))
saveRDS(aimecd_da_anon, "anondata/aimecd_da_anon.RDS")

teachers_anon <- teachers_clean %>% 
  mutate(teacher_enumerator = as.numeric(as.factor(Enumerator_Name))) %>% 
  select(-c(Enumerator_Name:Enumerator_Mobile, Permanent_Address:Head_Teacher_Contact, 
            SCHOOL_DETAILS:Teacher_Phone, startgeopointLatitude:startgeopointAccuracy,
            School_Name, Markaz, Moza)) 
saveRDS(teachers_anon, "anondata/teachers_anon.RDS")
